@@ -132,7 +132,7 @@ int PluginRunner::exec(const QString &name)
             if (!m_enginePath.isEmpty()) break;
         } 
         if (m_enginePath.isEmpty()) {
-            Utility::DisplayStdErrorDialog(tr("Error: Interpreter ") + m_engine + tr(" has no path set"));
+            Utility::DisplayStdErrorDialog(tr("Error: Interpreter") + " " + m_engine + " " + tr("has no path set"));
             reject();
             return QDialog::Rejected;
         }
@@ -145,14 +145,14 @@ int PluginRunner::exec(const QString &name)
         m_launcherPath = launcher_root + "/python/launcher.py";
         m_pluginPath = m_pluginsFolder + "/" + m_pluginName + "/" + "plugin.py";
         if (!QFileInfo(m_launcherPath).exists()) {
-            Utility::DisplayStdErrorDialog(tr("Installation Error: plugin launcher ") +
-                                           m_launcherPath + tr(" does not exist"));
+            Utility::DisplayStdErrorDialog(tr("Installation Error: plugin launcher") +
+                                           " " + m_launcherPath + " " + tr("does not exist"));
             reject();
             return QDialog::Rejected;
         }
     } else {
-        Utility::DisplayStdErrorDialog(tr("Error: plugin engine ") +
-                                       m_engine + tr(" is not supported (yet!)"));
+        Utility::DisplayStdErrorDialog(tr("Error: plugin engine") +
+                                       " " + m_engine + " " + tr("is not supported (yet!)"));
         reject();
         return QDialog::Rejected;
     }
@@ -201,6 +201,12 @@ void PluginRunner::writeSigilCFG()
 #endif
     cfg << settings.uiLanguage();
     cfg << settings.dictionary();
+    if (m_mainWindow->isWindowModified()) {
+        cfg << QString("True");
+    } else {
+        cfg << QString("False");
+    }
+    cfg << m_mainWindow->GetCurrentFilePath();
     QList <Resource *> selected_resources = m_bookBrowser->AllSelectedResources();
     foreach(Resource * resource, selected_resources) {
         cfg << resource->GetRelativePathToRoot();
@@ -362,7 +368,7 @@ void PluginRunner::startPlugin()
 #endif
 
     m_process.start(executable, args);
-    ui.statusLbl->setText("Status: running");
+    ui.statusLbl->setText(tr("Status: running"));
 
     // this starts the infinite progress bar
     ui.progressBar->setRange(0,0);
@@ -422,6 +428,11 @@ void PluginRunner::pluginFinished(int exitcode, QProcess::ExitStatus exitstatus)
 
     m_book->GetFolderKeeper()->SuspendWatchingResources();
 
+    if (!m_filesToAdd.isEmpty()) {
+        if (addFiles(m_filesToAdd)) {
+            book_modified = true;
+        }
+    }
     if (!m_filesToDelete.isEmpty()) {
         // before deleting make sure a tab of at least one of the remaining html files will be open
         // to prevent deleting the last tab when deleting resources
@@ -443,11 +454,6 @@ void PluginRunner::pluginFinished(int exitcode, QProcess::ExitStatus exitstatus)
             book_modified = true;
         }
     }
-    if (!m_filesToAdd.isEmpty()) {
-        if (addFiles(m_filesToAdd)) {
-            book_modified = true;
-        }
-    }
     if (!m_filesToModify.isEmpty()) {
         if (modifyFiles(m_filesToModify)) {
             book_modified = true;
@@ -475,7 +481,7 @@ void PluginRunner::pluginFinished(int exitcode, QProcess::ExitStatus exitstatus)
 #ifdef Q_OS_MAC
     }
 #endif
-    ui.statusLbl->setText("Status: " + m_result);
+    ui.statusLbl->setText(tr("Status:") + " " + m_result);
 
     // Validation plugins we auto close the plugin runner dialog
     // since they'll see the results in the results panel.
@@ -546,7 +552,7 @@ bool PluginRunner::processResultXML()
             if (name == "result") {
                 QString result = reader.readElementText();
                 m_result = result;
-                ui.textEdit->setPlainText(tr("Status: ") + result);
+                ui.textEdit->setPlainText(tr("Status:") + " " + result);
             } else if (name == "msg") {
                 QString msg = reader.readElementText();
                 ui.textEdit->append(msg);
@@ -675,11 +681,11 @@ bool PluginRunner::checkIsWellFormed()
     if (!xhtmlFilesToCheck.isEmpty()) {
         foreach (QString href, xhtmlFilesToCheck) {
             QString filePath = m_outputDir + "/" + href;
-            ui.statusLbl->setText("Status: checking " + href);
+            ui.statusLbl->setText(tr("Status: checking") + " " + href);
             QString data = Utility::ReadUnicodeTextFile(filePath);
             XhtmlDoc::WellFormedError error = XhtmlDoc::WellFormedErrorForSource(data);
             if (error.line != -1) {
-                errors.append(tr("Incorrect XHTML: ") + href + tr(" Line/Col ") + QString::number(error.line) +
+                errors.append(tr("Incorrect XHTML:") + " " + href + " " + tr("Line/Col") + " " + QString::number(error.line) +
                               "," + QString::number(error.column) + " " + error.message);
                 well_formed = false;
             }
@@ -690,7 +696,7 @@ bool PluginRunner::checkIsWellFormed()
             // can't really validate without a full dtd so
             // auto repair any xml file changes to be safe
             QString filePath = m_outputDir + "/" + href;
-            ui.statusLbl->setText("Status: checking " + href);
+            ui.statusLbl->setText(tr("Status: checking") + " " + href);
             QString mtype = "application/oebs-page-map+xml";
             if (href.endsWith(".opf")) mtype = "application/oebps-package+xml";
             if (href.endsWith(".ncx")) mtype = "application/x-dtbncx+xml";
@@ -750,7 +756,7 @@ bool PluginRunner::deleteFiles(const QStringList &files)
             continue;
         }
         if (resource) {
-            ui.statusLbl->setText(tr("Status: deleting ") + resource->Filename());
+            ui.statusLbl->setText(tr("Status: deleting") + " " + resource->Filename());
 
             if (tabResources.contains(resource)) {
                 m_tabManager->CloseTabForResource(resource);
@@ -789,7 +795,7 @@ bool PluginRunner::addFiles(const QStringList &files)
         if (m_pluginType == "input" && mime == "application/epub+zip") {
             QString epubPath = m_outputDir + "/" + href;
             QFileInfo fi(epubPath);
-            ui.statusLbl->setText(tr("Status: Loading ") + fi.fileName());
+            ui.statusLbl->setText(tr("Status: Loading") + " " + fi.fileName());
 #ifdef Q_OS_MAC
             MainWindow *new_window = new MainWindow(epubPath, true);
             new_window->show();
@@ -827,7 +833,7 @@ bool PluginRunner::addFiles(const QStringList &files)
         // No need to copy to ebook root as AddContentToFolder does that for us
         QString inpath = m_outputDir + "/" + href;
         QFileInfo fi(inpath);
-        ui.statusLbl->setText(tr("Status: adding ") + fi.fileName());
+        ui.statusLbl->setText(tr("Status: adding") + " " + fi.fileName());
 
         Resource *resource = m_book->GetFolderKeeper()->AddContentFileToFolder(inpath,false);
 
@@ -844,6 +850,10 @@ bool PluginRunner::addFiles(const QStringList &files)
         } else  if (resource->Type() == Resource::HTMLResourceType) {
             HTMLResource *html_resource = qobject_cast<HTMLResource *>(resource);
             html_resource->SetText(Utility::ReadUnicodeTextFile(inpath));
+            // remember to add this new file to the list of remaining xhtml resources
+            QString href = resource->GetRelativePathToRoot();
+            m_xhtmlFiles[href] = resource;
+            m_hrefToRes[href] = resource;
         } else if (resource->Type() == Resource::CSSResourceType) {
             CSSResource *css_resource = qobject_cast<CSSResource *>(resource);
             css_resource->SetText(Utility::ReadUnicodeTextFile(inpath));
@@ -893,7 +903,7 @@ bool PluginRunner::modifyFiles(const QStringList &files)
         QString inpath = m_outputDir + "/" + href;
         QString outpath = m_bookRoot + "/" + href;
         QFileInfo fi(outpath);
-        ui.statusLbl->setText(tr("Status: modifying ") + fi.fileName());
+        ui.statusLbl->setText(tr("Status: modifying") + " " + fi.fileName());
         Utility::ForceCopyFile(inpath, outpath);
         Resource *resource = m_hrefToRes.value(href);
         if (resource) {
