@@ -118,13 +118,7 @@ void BookBrowser::RefreshCounts()
     for (int i = 0; i < m_OPFModel->invisibleRootItem()->rowCount(); i++) {
         QStandardItem *folder = m_OPFModel->invisibleRootItem()->child(i);
         int count = folder->rowCount();
-        QString tooltip = QString("%1 ").arg(count);
-
-        if (count == 1) {
-            tooltip.append(tr("file"));
-        } else {
-            tooltip.append(tr("files"));
-        }
+        QString tooltip = QString(tr("%n file(s)","", count));
 
         folder->setToolTip(tooltip);
     }
@@ -613,7 +607,7 @@ QStringList BookBrowser::AddExisting(bool only_multimedia, bool only_images)
 
         QString filename = QFileInfo(filepath).fileName();
 
-        if (current_filenames.contains(filename)) {
+        if (current_filenames.contains(filename, Qt::CaseInsensitive )) {
             // If this is an image prompt to replace it.
             if (IMAGE_EXTENSIONS.contains(QFileInfo(filepath).suffix().toLower()) ||
                 SVG_EXTENSIONS.contains(QFileInfo(filepath).suffix().toLower()) ||
@@ -1419,14 +1413,14 @@ void BookBrowser::CreateContextMenuActions()
     sm->registerAction(this, m_CopyHTML, "MainWindow.BookBrowser.CopyHTML");
     m_Delete->setShortcut(QKeySequence::Delete);
     m_Merge->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M));
-    m_Merge->setToolTip("Merge with previous file, or merge multiple files into one.");
+    m_Merge->setToolTip(tr("Merge with previous file, or merge multiple files into one."));
     sm->registerAction(this, m_Merge, "MainWindow.BookBrowser.Merge");
     m_Rename->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_R));
-    m_Rename->setToolTip("Rename selected file(s)");
+    m_Rename->setToolTip(tr("Rename selected file(s)"));
     sm->registerAction(this, m_Rename, "MainWindow.BookBrowser.Rename");
-    m_LinkStylesheets->setToolTip("Link Stylesheets to selected file(s).");
+    m_LinkStylesheets->setToolTip(tr("Link Stylesheets to selected file(s)."));
     sm->registerAction(this, m_LinkStylesheets, "MainWindow.BookBrowser.LinkStylesheets");
-    m_AddSemantics->setToolTip("Add Semantics to selected file(s).");
+    m_AddSemantics->setToolTip(tr("Add Semantics to selected file(s)."));
     sm->registerAction(this, m_AddSemantics, "MainWindow.BookBrowser.AddSemantics");
     // Has to be added to the book browser itself as well
     // for the keyboard shortcut to work.
