@@ -204,14 +204,6 @@ void BookViewPreview::UpdateDisplay()
     }
 }
 
-void BookViewPreview::mouseReleaseEvent(QMouseEvent *event)
-{
-    // Propagate to base class
-    QWebView::mouseReleaseEvent(event);
-
-    emit GoToPreviewLocationRequest();
-}
-
 void BookViewPreview::ScrollToTop()
 {
     QString caret_location = "var elementList = document.getElementsByTagName(\"body\");"
@@ -533,10 +525,14 @@ QString BookViewPreview::GetElementSelectingJS_NoTextNodes(const QList<ViewEdito
     return element_selector;
 }
 
-QList<ViewEditor::ElementIndex> BookViewPreview::GetCaretLocation()
+QList<ViewEditor::ElementIndex> BookViewPreview::GetCaretLocation(bool normalize)
 {
     // The location element hierarchy encoded in a string
-    QString location_string = EvaluateJavascript(c_GetCaretLocation).toString();
+    QString normalize_tree = "";
+    if (normalize) {
+        normalize_tree = "document.normalize();";
+    }
+    QString location_string = EvaluateJavascript(normalize_tree % c_GetCaretLocation).toString();
     return ConvertQWebPathToHierarchy(location_string);
 }
 
@@ -776,6 +772,6 @@ void BookViewPreview::ConnectSignalsToSlots()
     connect(this,  SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(OpenContextMenu(const QPoint &)));
     connect(m_InspectElement,    SIGNAL(triggered()),  this, SLOT(InspectElement()));
     connect(page(), SIGNAL(loadFinished(bool)), this, SLOT(UpdateFinishedState(bool)));
-    connect(page(), SIGNAL(linkClicked(const QUrl &)), SIGNAL(LinkClicked(const QUrl &)));
+    connect(page(), SIGNAL(linkClicked(const QUrl &)), this, SIGNAL(LinkClicked(const QUrl &)));
     connect(page(), SIGNAL(loadFinished(bool)), this, SLOT(WebPageJavascriptOnLoad()));
 }
